@@ -67,7 +67,7 @@ def commonPreprocess(dataframe):
     return dataframe
 
 def keywordPool(csv):
-    pool = pd.read_csv(csv, sep=',', engine='python', encoding='latin-1')
+    pool = pd.read_csv(csv, sep=',', engine='python', quoting=csv.QUOTE_NONE, encoding='latin-1')
     column = ["brand", "string", "product_name"]
     pool.columns = column
 
@@ -82,7 +82,7 @@ def keywordPool(csv):
     return poolList
 
 def titleSummaryMaker(csv):
-    pool = pd.read_csv(csv, sep=',', engine='python', encoding='latin-1')
+    pool = pd.read_csv(csv, sep=',', engine='python', quoting=csv.QUOTE_NONE, encoding='latin-1')
     column = ["brand", "title_summary_temp", "title_summary"]
     pool.columns = column
 
@@ -116,16 +116,19 @@ def csvImporter_NEW(csv_folder, csv_folder_cleaned, keyword_pool):
         if "Laptops" in fileList[i]:
             db_table_name = 'tb_stackline_laptops'
             # commonPreprocess(dataframe)
+            print("Pool 검색 안함")
             stackTodb(dataframe, db_table_name)
 
         if "Earbuds" in fileList[i]:
             db_table_name = 'tb_stackline_earbuds'
             # commonPreprocess(dataframe)
+            print("Pool 검색 안함")
             stackTodb(dataframe, db_table_name)
 
         ##### pool
         if "Watches" in fileList[i]:
             db_table_name = 'tb_stackline_watches'
+            print("Pool 검색 시작")
 
             #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
             dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
@@ -141,6 +144,7 @@ def csvImporter_NEW(csv_folder, csv_folder_cleaned, keyword_pool):
 
         if "Tablets" in fileList[i]:
             db_table_name = 'tb_stackline_tablets'
+            print("Pool 검색 시작")
 
             #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
             dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
@@ -156,6 +160,7 @@ def csvImporter_NEW(csv_folder, csv_folder_cleaned, keyword_pool):
 
         if "Phones" in fileList[i]:
             db_table_name = 'tb_stackline_smartphones'
+            print("Pool 검색 시작")
 
             #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
             dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
